CREATE OR REPLACE FORCE EDITIONABLE VIEW "AROPS"."ROLE_PERM_POLICY_V" ("ID", "POLICY_NAME", "UNIQUE_POLICY_ID", "POLICY_DESCRIPTION", "CREATED_BY", "CHANGED_BY", "CREATION_TIME", "UPDATE_TIME", "DELETED", "CURRENT_STATE", "ACTUAL_STATE", "DETECTION_STATUS", "POLICY_RISK_MODE", "POLICY_RISK", "POLICY_COST", "OWNER_ID", "OWNER_NAME", "UNIQUE_PERMISSION_ID", "PERM_NAME", "PERMISSION_USER_ID", "PERMISSION_USER_NAME") AS 
SELECT DISTINCT policy.id,
    policy.name policy_name,
    policy.unique_policy_id,
    policy.description policy_description,
    policy.created_by,
    policy.changed_by,
    policy.creation_time,
    policy.update_time,
    policy.deleted,
        CASE
            WHEN ((policy.state = 'INACTIVE' AND policy.detection_status IS NULL) OR (policy.detection_status = 'INACTIVE')) THEN 'Inactive'
            WHEN ((policy.state = 'ACTIVE' AND policy.detection_status = 'COMPLETED') OR (policy.detection_status = 'RUNNING')) THEN 'Active'
            WHEN (policy.state = 'INACTIVE' AND policy.detection_status = 'INVALID') THEN 'Invalid from inactive'
            WHEN (policy.state = 'INVALID' AND policy.detection_status = 'INVALID') THEN 'Invalid from active'
            ELSE NULL
        END current_state,
    policy.state actual_state,
    policy.detection_status,
    TO_CHAR(policy.risk_mode) policy_risk_mode,
    policy.risk policy_risk,
    policy.cost policy_cost,
    (SELECT listagg(TO_CHAR(policy_owners_v.unique_owner_id), ', ')WITHIN GROUP(ORDER BY policy_owners_v.unique_owner_id) 
           FROM policy_owners_v
          WHERE policy.id = policy_owners_v.role_policy) owner_id,
    (SELECT listagg(TO_CHAR(policy_owners_v.owner_name), ', ')WITHIN GROUP(ORDER BY policy_owners_v.owner_name)
           FROM policy_owners_v
          WHERE policy.id = policy_owners_v.role_policy) owner_name,
    perm.unique_permission_id,
    perm.name perm_name,
    perm_user.unique_user_id permission_user_id,
    perm_user.display_name permission_user_name
   FROM role_policy policy
     LEFT JOIN policy_owner ON policy.id = policy_owner.role_policy
     LEFT JOIN role_permission role_perm ON policy.id = role_perm.policy
     LEFT JOIN spermission perm ON role_perm.unique_permission_id = perm.unique_permission_id AND perm.effective = '1'
     LEFT JOIN suser_account_permission_role role_user ON role_user.role = policy.id
     LEFT JOIN suser perm_user ON perm_user.id = role_user.suser
  GROUP BY policy.id, policy.name, policy.description, policy.created_by, policy.changed_by, policy.creation_time, policy.update_time, policy.deleted,
        CASE
            WHEN ((policy.state = 'INACTIVE' AND policy.detection_status IS NULL) OR (policy.detection_status = 'INACTIVE')) THEN 'Inactive'
            WHEN ((policy.state = 'ACTIVE' AND policy.detection_status = 'COMPLETED') OR (policy.detection_status = 'RUNNING')) THEN 'Active'
            WHEN (policy.state = 'INACTIVE' AND policy.detection_status = 'INVALID') THEN 'Invalid from inactive'
            WHEN (policy.state = 'INVALID' AND policy.detection_status = 'INVALID') THEN 'Invalid from active'
            ELSE NULL
        END, policy.state, policy.detection_status, policy.risk_mode, policy.risk, policy.cost, perm.unique_permission_id, perm.name, policy.unique_policy_id, perm_user.unique_user_id, perm_user.display_name;